function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import { bool, shape, number, arrayOf, string } from 'prop-types';
import { connect, Query } from "@magento/venia-drivers";
import { addItemToCart } from "../../actions/cart";
import { loadingIndicator } from "../../components/LoadingIndicator";
import ProductFullDetail from "../../components/ProductFullDetail";
import getUrlKey from "../../util/getUrlKey";
import productQuery from "../../queries/getProductDetail.graphql";
/**
 * As of this writing, there is no single Product query type in the M2.3 schema.
 * The recommended solution is to use filter criteria on a Products query.
 * However, the `id` argument is not supported. See
 * https://github.com/magento/graphql-ce/issues/86
 * TODO: Replace with a single product query when possible.
 */

class Product extends Component {
  constructor(...args) {
    super(...args);

    _defineProperty(this, "addToCart", async (item, quantity) => {
      const {
        guestCartId
      } = this.props;
      await this.props.addItemToCart({
        guestCartId,
        item,
        quantity
      });
    });
  }

  render() {
    return React.createElement(Query, {
      query: productQuery,
      variables: {
        urlKey: getUrlKey(),
        onServer: false
      }
    }, ({
      loading,
      error,
      data
    }) => {
      if (error) return React.createElement("div", null, "Data Fetch Error");
      if (loading) return loadingIndicator;
      const product = data.productDetail.items[0];
      return React.createElement(ProductFullDetail, {
        product: product,
        addToCart: this.props.addItemToCart
      });
    });
  }

}

_defineProperty(Product, "propTypes", {
  data: shape({
    productDetail: shape({
      total_count: number,
      items: arrayOf(shape({
        id: number,
        sku: string.isRequired,
        price: shape({
          regularPrice: shape({
            amount: shape({
              currency: string.isRequired,
              value: number.isRequired
            })
          }).isRequired
        }).isRequired,
        image: string,
        image_label: string,
        media_gallery_entries: arrayOf(shape({
          label: string,
          position: number.isRequired,
          disabled: bool,
          file: string.isRequired
        })),
        description: string,
        short_description: string,
        canonical_url: string
      })).isRequired
    }).isRequired
  })
});

const mapDispatchToProps = {
  addItemToCart
};
export default connect(null, mapDispatchToProps)(Product);
//# sourceMappingURL=Product.js.map